--- src/_webp.c-orig	2020-01-02 11:33:30.000000000 +0300
+++ src/_webp.c	2022-11-27 02:43:24.193119000 +0300
@@ -22,6 +22,62 @@
 
 #endif
 
+typedef int (*Importer)(WebPPicture* const, const uint8_t* const, int);
+
+/* copy from libwebp with config.method = 6 */
+static size_t _p_Encode(const uint8_t* rgba, int width, int height, int stride,
+                     Importer import, float quality_factor, int lossless,
+                     uint8_t** output) {
+  WebPPicture pic;
+  WebPConfig config;
+  WebPMemoryWriter wrt;
+  int ok;
+
+  if (output == NULL) return 0;
+
+  if (!WebPConfigPreset(&config, WEBP_PRESET_DEFAULT, quality_factor) ||
+      !WebPPictureInit(&pic)) {
+    return 0;  // shouldn't happen, except if system installation is broken
+  }
+
+  config.lossless = !!lossless;
+  config.method = 6;
+  pic.use_argb = !!lossless;
+  pic.width = width;
+  pic.height = height;
+  pic.writer = WebPMemoryWrite;
+  pic.custom_ptr = &wrt;
+  WebPMemoryWriterInit(&wrt);
+
+  ok = import(&pic, rgba, stride) && WebPEncode(&config, &pic);
+  WebPPictureFree(&pic);
+  if (!ok) {
+    WebPMemoryWriterClear(&wrt);
+    *output = NULL;
+    return 0;
+  }
+  *output = wrt.mem;
+  return wrt.size;
+}
+
+#define ENCODE_FUNC(NAME, IMPORTER)                                     \
+size_t NAME(const uint8_t* in, int w, int h, int bps, float q,          \
+            uint8_t** out) {                                            \
+  return _p_Encode(in, w, h, bps, IMPORTER, q, 0, out);                    \
+}
+
+ENCODE_FUNC(_p_WebPEncodeRGB, WebPPictureImportRGB)
+ENCODE_FUNC(_p_WebPEncodeRGBA, WebPPictureImportRGBA)
+
+#define LOSSLESS_DEFAULT_QUALITY 100.
+#define LOSSLESS_ENCODE_FUNC(NAME, IMPORTER)                                 \
+size_t NAME(const uint8_t* in, int w, int h, int bps, uint8_t** out) {       \
+  return _p_Encode(in, w, h, bps, IMPORTER, LOSSLESS_DEFAULT_QUALITY, 1, out);  \
+}
+
+LOSSLESS_ENCODE_FUNC(_p_WebPEncodeLosslessRGB, WebPPictureImportRGB)
+LOSSLESS_ENCODE_FUNC(_p_WebPEncodeLosslessRGBA, WebPPictureImportRGBA)
+
 /* -------------------------------------------------------------------- */
 /* WebP Muxer Error Handling                                            */
 /* -------------------------------------------------------------------- */
@@ -568,11 +624,11 @@
         }
         #if WEBP_ENCODER_ABI_VERSION >= 0x0100
         if (lossless) {
-            ret_size = WebPEncodeLosslessRGBA(rgb, width, height, 4 * width, &output);
+            ret_size = _p_WebPEncodeLosslessRGBA(rgb, width, height, 4 * width, &output);
         } else
         #endif
         {
-            ret_size = WebPEncodeRGBA(rgb, width, height, 4 * width, quality_factor, &output);
+            ret_size = _p_WebPEncodeRGBA(rgb, width, height, 4 * width, quality_factor, &output);
         }
     } else if (strcmp(mode, "RGB")==0){
         if (size < width * height * 3){
@@ -580,11 +636,11 @@
         }
         #if WEBP_ENCODER_ABI_VERSION >= 0x0100
         if (lossless) {
-            ret_size = WebPEncodeLosslessRGB(rgb, width, height, 3 * width, &output);
+            ret_size = _p_WebPEncodeLosslessRGB(rgb, width, height, 3 * width, &output);
         } else
         #endif
         {
-            ret_size = WebPEncodeRGB(rgb, width, height, 3 * width, quality_factor, &output);
+            ret_size = _p_WebPEncodeRGB(rgb, width, height, 3 * width, quality_factor, &output);
         }
     } else {
         Py_RETURN_NONE;
